==> pegasus-support-2.2.5-sources.jar: com/thebeastshop/support/vo/cart/CartProductPackVO.java <==
package com.thebeastshop.support.vo.cart;

import com.google.common.collect.Lists;
import com.thebeastshop.support.Label;
import com.thebeastshop.support.enums.CartPackSource;
import com.thebeastshop.support.vo.campaign.GiftCampaignVO;
import com.thebeastshop.support.vo.customize.UserSingleCustomization;
import com.thebeastshop.support.vo.lesson.CourseTime;
import com.thebeastshop.support.vo.product.SpvVO;

import java.io.Serializable;
import java.util.Collection;
import java.util.List;

/**
 * 商品包
 *
 * @author Paul-xiong
 */
public class CartProductPackVO implements Serializable {
	/**
	 *
	 */
	private static final long serialVersionUID = 7949689391932894329L;
	/**
	 * 
	 */
	private Long id;
	/**
	 * 数量
	 */
	private int count = 1;

	/**
	 * 门店发货数量
	 */
	private int storeCount;
	
	/**
	 * 仓库发货数量
	 */
	private int warehouseCount;

    /**
     * 配送信息
     */
    private List<DeliveryVO> deliverys;

    /**
	 * 商品包来源
	 */
	private CartPackSource source = CartPackSource.RAW;
	/**
	 * 商品code
	 */
	private String productId;
	/**
	 * spv信息
	 */
	private SpvVO spv;
	/**
	 * 是否包含规格
	 */
	private boolean hasVariants;
	/**
	 * 标签
	 */
	private Collection<Label> labels = Lists.newArrayList();
    /**
     * 赠品商品(订单)
     */
    private List<CartProductPackVO> giftPacks;
	/**
	 * 赠品商品(购物车)
	 */
	private List<GiftCampaignVO> giftCampaigns;
	/**
	 * 是否已获得（加价购才有）
	 */
	private Boolean owned = false;
	
	/**
	 * 是否来单
	 */
	private Boolean isJit = false;
	/**
	 * 是否预售
	 */
	private Boolean isPresell = false;
	
	/**
	 * 是否定制商品
	 */
	private Boolean customizable = false;
	
	/**
	 * 该商品用户是否已经定制过，若定制过，则不允许用户再修改 spv 信息
	 */
	private Boolean customized = false;
	/**
	 * 定制内容
	 */
	private String customizeInfo;
	/**
	 * 定制属性集
	 */
	private List<UserSingleCustomization> customizes;
	/**
	 * 权益对象
	 */
	private CartBenefitVO benefit;
	/**
	 * 参加的赠品活动
	 */
	private PackCampaignVO campaign;

    /**
     * 场次信息
     */
    private CourseTime courseTime;
    /**
     *
     */
    private InvalidVO invalid = new InvalidVO();
    
	/**
	 * 配送描述
	 */
	private String sendDesc;

    /**
     * 活动阶梯ID
     */
    private Integer campaignSectionId;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public int getCount() {
        return count;
    }

    public void setCount(int count) {
        this.count = count;
    }

    public int getStoreCount() {
        return storeCount;
    }

    public void setStoreCount(int storeCount) {
        this.storeCount = storeCount;
    }

    public int getWarehouseCount() {
        return warehouseCount;
    }

    public void setWarehouseCount(int warehouseCount) {
        this.warehouseCount = warehouseCount;
    }

    public List<DeliveryVO> getDeliverys() {
        return deliverys;
    }

    public void setDeliverys(List<DeliveryVO> deliverys) {
        this.deliverys = deliverys;
    }

    public CartPackSource getSource() {
        return source;
    }

    public void setSource(CartPackSource source) {
        this.source = source;
    }

    public String getProductId() {
        return productId;
    }

    public void setProductId(String productId) {
        this.productId = productId;
    }

    public SpvVO getSpv() {
        return spv;
    }

    public void setSpv(SpvVO spv) {
        this.spv = spv;
    }

    public boolean isHasVariants() {
        return hasVariants;
    }

    public void setHasVariants(boolean hasVariants) {
        this.hasVariants = hasVariants;
    }

    public Collection<Label> getLabels() {
        return labels;
    }

    public void setLabels(Collection<Label> labels) {
        this.labels = labels;
    }

    public List<CartProductPackVO> getGiftPacks() {
        return giftPacks;
    }

    public void setGiftPacks(List<CartProductPackVO> giftPacks) {
        this.giftPacks = giftPacks;
    }

    public List<GiftCampaignVO> getGiftCampaigns() {
        return giftCampaigns;
    }

    public void setGiftCampaigns(List<GiftCampaignVO> giftCampaigns) {
        this.giftCampaigns = giftCampaigns;
    }

    public Boolean getOwned() {
        return owned;
    }

    public void setOwned(Boolean owned) {
        this.owned = owned;
    }

    public Boolean getIsJit() {
        return isJit;
    }

    public void setIsJit(Boolean isJit) {
        this.isJit = isJit;
    }


	public List<UserSingleCustomization> getCustomizes() {
		return customizes;
	}
    public Boolean getPresell() {
        return isPresell;
    }

    public void setPresell(Boolean presell) {
        isPresell = presell;
    }

    public Boolean getCustomizable() {
        return customizable;
    }

    public void setCustomizable(Boolean customizable) {
        this.customizable = customizable;
    }

    public Boolean getCustomized() {
        return customized;
    }

    public void setCustomized(Boolean customized) {
        this.customized = customized;
    }

    public String getCustomizeInfo() {
        return customizeInfo;
    }

    public void setCustomizeInfo(String customizeInfo) {
        this.customizeInfo = customizeInfo;
    }

    public Integer getCampaignSectionId() {
        return campaignSectionId;
    }

    public void setCampaignSectionId(Integer campaignSectionId) {
        this.campaignSectionId = campaignSectionId;
    }

    @Override
	public String toString() {
		final StringBuilder sb = new StringBuilder("CartProductPackVO{");
		sb.append("id=").append(id);
		sb.append(", count=").append(count);
		sb.append(", source=").append(source);
		sb.append(", productId='").append(productId).append('\'');
		sb.append(", spv=").append(spv);
		sb.append(", hasVariants=").append(hasVariants);
		sb.append(", labels=").append(labels);
        sb.append(", giftPacks=").append(giftPacks);
        sb.append(", giftCampaigns=").append(giftCampaigns);
		sb.append(", owned=").append(owned);
		sb.append(", customized=").append(customized);
		sb.append(", customizeInfo='").append(customizeInfo).append('\'');
		sb.append(", customizes=").append(customizes);
		sb.append(", isJit=").append(isJit);
		sb.append(", isPresell=").append(isPresell);
		sb.append(", benefit=").append(benefit);
		sb.append(", campaign=").append(campaign);
		sb.append('}');
		return sb.toString();
	}

    public void setCustomizes(List<UserSingleCustomization> customizes) {
        this.customizes = customizes;
    }

    public CartBenefitVO getBenefit() {
        return benefit;
    }

    public void setBenefit(CartBenefitVO benefit) {
        this.benefit = benefit;
    }

    public PackCampaignVO getCampaign() {
        return campaign;
    }

    public void setCampaign(PackCampaignVO campaign) {
        this.campaign = campaign;
    }

    public InvalidVO getInvalid() {
        return invalid;
    }

    public void setInvalid(InvalidVO invalid) {
        this.invalid = invalid;
    }

    public CourseTime getCourseTime() {
        return courseTime;
    }

    public void setCourseTime(CourseTime courseTime) {
        this.courseTime = courseTime;
    }

  
    public Boolean getIsPresell() {
		return isPresell;
	}

	public void setIsPresell(Boolean isPresell) {
		this.isPresell = isPresell;
	}

	public String getSendDesc() {
		return sendDesc;
	}

	public void setSendDesc(String sendDesc) {
		this.sendDesc = sendDesc;
	}


	public static class PackCampaignVO implements Serializable {

        /**
         *
         */
        private static final long serialVersionUID = 1L;

        private Long id;

        private String name;

        private InfoVO info;

        public Long getId() {
            return id;
        }

        public void setId(Long id) {
            this.id = id;
        }

        public String getName() {
            return name;
        }

        public void setName(String name) {
            this.name = name;
        }

        public InfoVO getInfo() {
            return info;
        }

        public void setInfo(InfoVO info) {
            this.info = info;
        }

        public static class InfoVO implements Serializable {

            /**
             *
             */
            private static final long serialVersionUID = 1L;

            private String type;

            private String typeColor = "#FFFFFF";

            private String typeBgColor = "#000000";

            private String summaryColor = "#FFFFFF";

            public String getType() {
                return type;
            }

            public void setType(String type) {
                this.type = type;
            }

            public String getTypeColor() {
                return typeColor;
            }

            public void setTypeColor(String typeColor) {
                this.typeColor = typeColor;
            }

            public String getTypeBgColor() {
                return typeBgColor;
            }

            public void setTypeBgColor(String typeBgColor) {
                this.typeBgColor = typeBgColor;
            }

            public String getSummaryColor() {
                return summaryColor;
            }

            public void setSummaryColor(String summaryColor) {
                this.summaryColor = summaryColor;
            }

        }

    }

    public static class InvalidVO implements Serializable {

        private Boolean invalid = false;

        private String desc;

        public Boolean getInvalid() {
            return invalid;
        }

        public void setInvalid(Boolean invalid) {
            this.invalid = invalid;
        }

        public String getDesc() {
            return desc;
        }

        public void setDesc(String desc) {
            this.desc = desc;
        }
    }

}

==> pegasus-support-2.3.10-sources.jar: com/thebeastshop/support/vo/cart/CartProductPackVO.java <==
package com.thebeastshop.support.vo.cart;

import com.google.common.collect.Lists;
import com.thebeastshop.support.Label;
import com.thebeastshop.support.enums.CartPackSource;
import com.thebeastshop.support.enums.DeliverCalType;
import com.thebeastshop.support.vo.campaign.GiftCampaignVO;
import com.thebeastshop.support.vo.customize.UserSingleCustomization;
import com.thebeastshop.support.vo.lesson.CourseTime;
import com.thebeastshop.support.vo.product.SpvVO;

import java.io.Serializable;
import java.util.Collection;
import java.util.List;

/**
 * 商品包
 *
 * @author Paul-xiong
 */
public class CartProductPackVO implements Serializable {
    /**
     *
     */
    private static final long serialVersionUID = 7949689391932894329L;
    /**
     *
     */
    private Long id;
    /**
     * 数量
     */
    private int count = 1;

    /**
     * 门店发货数量
     */
    private int storeCount;

    /**
     * 仓库发货数量
     */
    private int warehouseCount;

    /**
     * 配送信息
     */
    private List<DeliveryVO> deliverys;

    /**
     * 商品包来源
     */
    private CartPackSource source = CartPackSource.RAW;
    /**
     * 商品code
     */
    private String productId;
    /**
     * spv信息
     */
    private SpvVO spv;
    /**
     * 是否包含规格
     */
    private boolean hasVariants;
    /**
     * 标签
     */
    private Collection<Label> labels = Lists.newArrayList();
    /**
     * 赠品商品(订单)
     */
    private List<CartProductPackVO> giftPacks;
    /**
     * 赠品商品(购物车)
     */
    private List<GiftCampaignVO> giftCampaigns;
    /**
     * 是否已获得（加价购才有）
     */
    private Boolean owned = false;

    /**
     * 是否来单
     */
    private Boolean isJit = false;
    /**
     * 是否预售
     */
    private Boolean isPresell = false;

    /**
     * 是否定制商品
     */
    private Boolean customizable = false;

    /**
     * 该商品用户是否已经定制过，若定制过，则不允许用户再修改 spv 信息
     */
    private Boolean customized = false;
    /**
     * 定制内容
     */
    private String customizeInfo;
    /**
     * 定制属性集
     */
    private List<UserSingleCustomization> customizes;
    /**
     * 权益对象
     */
    private CartBenefitVO benefit;
    /**
     * 参加的赠品活动
     */
    private PackCampaignVO campaign;

    /**
     * 场次信息
     */
    private CourseTime courseTime;
    /**
     *
     */
    private InvalidVO invalid = new InvalidVO();

    /**
     * 配送描述
     */
    private String sendDesc;

    /**
     * 活动阶梯ID
     */
    private Integer campaignSectionId;


    private DeliverFeeVO deliverFee;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public int getCount() {
        return count;
    }

    public void setCount(int count) {
        this.count = count;
    }

    public int getStoreCount() {
        return storeCount;
    }

    public void setStoreCount(int storeCount) {
        this.storeCount = storeCount;
    }

    public int getWarehouseCount() {
        return warehouseCount;
    }

    public void setWarehouseCount(int warehouseCount) {
        this.warehouseCount = warehouseCount;
    }

    public List<DeliveryVO> getDeliverys() {
        return deliverys;
    }

    public void setDeliverys(List<DeliveryVO> deliverys) {
        this.deliverys = deliverys;
    }

    public CartPackSource getSource() {
        return source;
    }

    public void setSource(CartPackSource source) {
        this.source = source;
    }

    public String getProductId() {
        return productId;
    }

    public void setProductId(String productId) {
        this.productId = productId;
    }

    public SpvVO getSpv() {
        return spv;
    }

    public void setSpv(SpvVO spv) {
        this.spv = spv;
    }

    public boolean isHasVariants() {
        return hasVariants;
    }

    public void setHasVariants(boolean hasVariants) {
        this.hasVariants = hasVariants;
    }

    public Collection<Label> getLabels() {
        return labels;
    }

    public void setLabels(Collection<Label> labels) {
        this.labels = labels;
    }

    public List<CartProductPackVO> getGiftPacks() {
        return giftPacks;
    }

    public void setGiftPacks(List<CartProductPackVO> giftPacks) {
        this.giftPacks = giftPacks;
    }

    public List<GiftCampaignVO> getGiftCampaigns() {
        return giftCampaigns;
    }

    public void setGiftCampaigns(List<GiftCampaignVO> giftCampaigns) {
        this.giftCampaigns = giftCampaigns;
    }

    public Boolean getOwned() {
        return owned;
    }

    public void setOwned(Boolean owned) {
        this.owned = owned;
    }

    public Boolean getIsJit() {
        return isJit;
    }

    public void setIsJit(Boolean isJit) {
        this.isJit = isJit;
    }


    public List<UserSingleCustomization> getCustomizes() {
        return customizes;
    }

    public Boolean getPresell() {
        return isPresell;
    }

    public void setPresell(Boolean presell) {
        isPresell = presell;
    }

    public Boolean getCustomizable() {
        return customizable;
    }

    public void setCustomizable(Boolean customizable) {
        this.customizable = customizable;
    }

    public Boolean getCustomized() {
        return customized;
    }

    public void setCustomized(Boolean customized) {
        this.customized = customized;
    }

    public String getCustomizeInfo() {
        return customizeInfo;
    }

    public void setCustomizeInfo(String customizeInfo) {
        this.customizeInfo = customizeInfo;
    }

    public Integer getCampaignSectionId() {
        return campaignSectionId;
    }

    public void setCampaignSectionId(Integer campaignSectionId) {
        this.campaignSectionId = campaignSectionId;
    }

    public void setCustomizes(List<UserSingleCustomization> customizes) {
        this.customizes = customizes;
    }

    public CartBenefitVO getBenefit() {
        return benefit;
    }

    public void setBenefit(CartBenefitVO benefit) {
        this.benefit = benefit;
    }

    public PackCampaignVO getCampaign() {
        return campaign;
    }

    public void setCampaign(PackCampaignVO campaign) {
        this.campaign = campaign;
    }

    public InvalidVO getInvalid() {
        return invalid;
    }

    public void setInvalid(InvalidVO invalid) {
        this.invalid = invalid;
    }

    public CourseTime getCourseTime() {
        return courseTime;
    }

    public void setCourseTime(CourseTime courseTime) {
        this.courseTime = courseTime;
    }


    public Boolean getIsPresell() {
        return isPresell;
    }

    public void setIsPresell(Boolean isPresell) {
        this.isPresell = isPresell;
    }

    public String getSendDesc() {
        return sendDesc;
    }

    public void setSendDesc(String sendDesc) {
        this.sendDesc = sendDesc;
    }

    public DeliverFeeVO getDeliverFee() {
        return deliverFee;
    }

    public void setDeliverFee(DeliverFeeVO deliverFee) {
        this.deliverFee = deliverFee;
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder("CartProductPackVO{");
        sb.append("id=").append(id);
        sb.append(", count=").append(count);
        sb.append(", source=").append(source);
        sb.append(", productId='").append(productId).append('\'');
        sb.append(", spv=").append(spv);
        sb.append(", hasVariants=").append(hasVariants);
        sb.append(", labels=").append(labels);
        sb.append(", giftPacks=").append(giftPacks);
        sb.append(", giftCampaigns=").append(giftCampaigns);
        sb.append(", owned=").append(owned);
        sb.append(", customized=").append(customized);
        sb.append(", customizeInfo='").append(customizeInfo).append('\'');
        sb.append(", customizes=").append(customizes);
        sb.append(", isJit=").append(isJit);
        sb.append(", isPresell=").append(isPresell);
        sb.append(", benefit=").append(benefit);
        sb.append(", campaign=").append(campaign);
        sb.append(", deliverFee=").append(deliverFee);
        sb.append('}');
        return sb.toString();
    }


    public static class PackCampaignVO implements Serializable {

        /**
         *
         */
        private static final long serialVersionUID = 1L;

        private Long id;

        private String name;

        private InfoVO info;

        public Long getId() {
            return id;
        }

        public void setId(Long id) {
            this.id = id;
        }

        public String getName() {
            return name;
        }

        public void setName(String name) {
            this.name = name;
        }

        public InfoVO getInfo() {
            return info;
        }

        public void setInfo(InfoVO info) {
            this.info = info;
        }

        public static class InfoVO implements Serializable {

            /**
             *
             */
            private static final long serialVersionUID = 1L;

            private String type;

            private String typeColor = "#FFFFFF";

            private String typeBgColor = "#000000";

            private String summaryColor = "#FFFFFF";

            public String getType() {
                return type;
            }

            public void setType(String type) {
                this.type = type;
            }

            public String getTypeColor() {
                return typeColor;
            }

            public void setTypeColor(String typeColor) {
                this.typeColor = typeColor;
            }

            public String getTypeBgColor() {
                return typeBgColor;
            }

            public void setTypeBgColor(String typeBgColor) {
                this.typeBgColor = typeBgColor;
            }

            public String getSummaryColor() {
                return summaryColor;
            }

            public void setSummaryColor(String summaryColor) {
                this.summaryColor = summaryColor;
            }

        }

    }

    public static class InvalidVO implements Serializable {

        private Boolean invalid = false;

        private String desc;

        public Boolean getInvalid() {
            return invalid;
        }

        public void setInvalid(Boolean invalid) {
            this.invalid = invalid;
        }

        public String getDesc() {
            return desc;
        }

        public void setDesc(String desc) {
            this.desc = desc;
        }
    }

    public static class DeliverFeeVO implements Serializable {
        private DeliverCalType deliverCalType = DeliverCalType.Fixed;
        private String deliverFeeTip;

        public DeliverCalType getDeliverCalType() {
            return deliverCalType;
        }

        public void setDeliverCalType(DeliverCalType deliverCalType) {
            this.deliverCalType = deliverCalType;
        }

        public String getDeliverFeeTip() {
            return deliverFeeTip;
        }

        public void setDeliverFeeTip(String deliverFeeTip) {
            this.deliverFeeTip = deliverFeeTip;
        }
    }
}
